@@ -2,4 +2,6 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 /// Definitions for retrieval of market data bars.
-pub mod stocks;
+pub mod bars;
+/// Functionality for retrieval of most recent quotes.
+pub mod last_quote;
